#!/bin/sh
# Schedwi
# Copyright (C) 2007 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


# mod_shell_mail.sh
# Send an e-mail when the status of a job/jobset changes.
# This script is called by the Schedwi Server (schedwisrv) through its
# mod_shell module whenever the status of a job/joset changes.
# The job/jobset name and ID, as well as the previous and new status are
# provided through environment variables:
#
#    SCHEDWI_JOBPATH=<full path of the job/jobset>
#    SCHEDWI_JOBID=<workload>_<id>
#    SCHEDWI_STATUS_NEW=<new status>
#    SCHEDWI_STATUS_OLD=<previous statu>
#
# The values of SCHEDWI_STATUS_NEW and SCHEDWI_STATUS_OLD can be:
#    WAITING
#    RUNNING
#    COMPLETED
#    FAILED
#
# Installation:
#
# 1/ Edit this script to adapt the `TO', `CC' and `BCC' variables to your
#    environment.
# 2/ Enable the mod_shell module and activate the mod_shell_mail.sh script.
#    Edit the schedwisrv configuration file (schedwisrv.conf) and set
#    the variables as follow:
#       MODULE_LOAD=mod_shell
#       MODULE:mod_shell:CMD_STATUS=/usr/libexec/schedwisrv/mod_shell_mail.sh
# 3/ Restart the schedwisrv daemon
#


#--
#-- The following variables must be adapted to your environment
#--

#-- Mail recipient (the addresses must be separated by commas)
TO="yourname@yourcompany.com,othername2@yourcompany.com"

#-- Optionnal (comment out by `#' if not needed).  Carbon copies recipients
#-- (the addresses must be separated by commas)
CC="copyname1@yourcompany.com,copyname2@yourcompany.com"

#-- Optionnal (comment out by `#' if not needed).  Blind carbon copies
#-- recipients (the addresses must be separated by commas)
BCC="blindcopyname1@yourcompany.com,blindcopyname2@yourcompany.com"

#-- Mail subject
SUBJECT="Job/jobset $SCHEDWI_JOBPATH new status $SCHEDWI_STATUS_NEW"


#--
#-- You shouldn't have to modify the script below this comment (except maybe
#-- for the content of the message to send)
#--

#-- Set a basic default path as mod_script calls this script without setting
#-- this variable
PATH=/bin:/usr/bin:/usr/local/bin:/usr/sbin:/sbin
export PATH

#-- Build the `mail' command parameters
PARAMS=""

#-- At least a mail recipient must be set (in `TO').  If not, exit
if [ "$TO" = "" ]
then
	exit 0
fi

#-- Subject
if [ "$SUBJECT" != "" ]
then
	PARAMS="$PARAMS -s \"$SUBJECT\""
fi

#-- Carbon copies recipients
if [ "$CC" != "" ]
then
	PARAMS="$PARAMS -c \"$CC\""
fi

#-- Blind carbon copies recipients
if [ "$BCC" != "" ]
then
	PARAMS="$PARAMS -b \"$BCC\""
fi

#-- Send the mail
#-- The message can be customised if need be
eval mail $PARAMS "$TO" <<EOF
Hello,

The job/jobset $SCHEDWI_JOBPATH (id $SCHEDWI_JOBID) is $SCHEDWI_STATUS_NEW.
Its previous status was $SCHEDWI_STATUS_OLD.

Regards,

The Schedwi Server
EOF

exit 0

#-----------------============== End Of File ==============-----------------
