#!/bin/sh
# Schedwi
# Copyright (C) 2007 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


# mod_shell_nagios.sh
# Send a Nagios message when the status of a job/jobset changes.
# This script is called by the Schedwi Server (schedwisrv) through its
# mod_shell module whenever the status of a job/joset changes.
# The status is then forwarded to a Nagios Monitoring server through
# NCSA (via the send_nsca command).
# The job/jobset name and ID, as well as the previous and new status are
# provided through environment variables:
#
#    SCHEDWI_JOBPATH=<full path of the job/jobset>
#    SCHEDWI_JOBID=<workload>_<id>
#    SCHEDWI_STATUS_NEW=<new status>
#    SCHEDWI_STATUS_OLD=<previous statu>
#
# The values of SCHEDWI_STATUS_NEW and SCHEDWI_STATUS_OLD can be:
#    WAITING
#    RUNNING
#    COMPLETED
#    FAILED
#
# Installation:
#
# 1/ Edit this script to adapt the variables in the first part (NAGIOS_SERVER,
#    NAGIOS_PORT, CLIENT, SERVICE, ...)
# 2/ Enable the mod_shell module and activate the mod_shell_nagios.sh script.
#    Edit the schedwisrv configuration file (schedwisrv.conf) and set
#    the variables as follow:
#       MODULE_LOAD=mod_shell
#       MODULE:mod_shell:CMD_STATUS=/usr/libexec/schedwisrv/mod_shell_nagios.sh
# 3/ Restart the schedwisrv daemon
#


#--
#-- The following variables must be adapted to your environment
#--

#-- The IP address of the host running the NSCA daemon
NAGIOS_SERVER="nagios.yourcompany.com"

#-- The port on which the daemon is running (leave empty to use default)
NAGIOS_PORT=""

#-- Number of seconds before connection attempt times out
#-- (leave empty to use default)
NAGIOS_TIMEOUT=""

#-- Name of the send_nsca configuration file to use
#-- (leave empty to use default)
NAGIOS_CONF=""

#-- Host name as defined in Nagios (short name of host that the service is
#-- associated with)
CLIENT=`hostname | cut -d '.' -f1`

#-- Service name as defined in Nagios
SERVICE="schedwi"

#-- Message sent to Nagios
MESSAGE="Job/jobset $SCHEDWI_JOBPATH new status $SCHEDWI_STATUS_NEW"


#--
#-- You shouldn't have to modify the script below this comment
#--

#-- Set a basic default path as mod_script calls this script without setting
#-- this variable.  The send_nsca command must be in one of these paths
PATH=/bin:/usr/bin:/usr/local/bin:/usr/sbin:/sbin
export PATH


#-- Build the `send_nsca' command parameters
PARAMS=""

#-- NSCA listening port on the Nagios server
if [ "$NAGIOS_PORT" != "" ]
then
	PARAMS="$PARAMS -p $NAGIOS_PORT"
fi

#-- Timeout
if [ "$NAGIOS_TIMEOUT" != "" ]
then
	PARAMS="$PARAMS -to $NAGIOS_TIMEOUT"
fi

#-- send_nsca configuration file
if [ "$NAGIOS_CONF" != "" ]
then
	PARAMS="$PARAMS -c \"$NAGIOS_CONF\""
fi

#-- Set the Nagios status (0=OK, 1=WARNING, 2=CRITICAL, 3=UNKNOWN) depending
#-- of the jobs status
case $SCHEDWI_STATUS_NEW in
	WAITING)
		RET=0;;
	RUNNING)
		RET=0;;
	COMPLETED)
		RET=0;;
	FAILED)
		RET=2;;
	*)
		RET=3;;
esac

#-- Call the send_nsca command.  Warning: the field separators is a tabulation
eval send_nsca -H "$NAGIOS_SERVER" $PARAMS <<EOF
$CLIENT	$SERVICE	$RET	$MESSAGE
EOF

exit 0

#-----------------============== End Of File ==============-----------------
