#!/bin/sh
# Schedwi
# Copyright (C) 2007 Herve Quatremain
#
# This file is part of Schedwi.
#
# Schedwi is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or
# (at your option) any later version.
#
# Schedwi is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


# mod_shell_snmp.sh
# Send a SNMP trap when the status of a job/jobset changes.
# This script is called by the Schedwi Server (schedwisrv) through its
# mod_shell module whenever the status of a job/joset changes.
# The status is then forwarded to a SNMP Monitoring server through a SNMP
# trap (via the snmptrap command).
# The job/jobset name and ID, as well as the previous and new status are
# provided through environment variables:
#
#    SCHEDWI_JOBPATH=<full path of the job/jobset>
#    SCHEDWI_JOBID=<workload>_<id>
#    SCHEDWI_STATUS_NEW=<new status>
#    SCHEDWI_STATUS_OLD=<previous statu>
#
# The values of SCHEDWI_STATUS_NEW and SCHEDWI_STATUS_OLD can be:
#    WAITING
#    RUNNING
#    COMPLETED
#    FAILED
#
# Installation:
#
# 1/ Edit this script to adapt the variables in the first part (SNMP_SERVER,
#    MESSAGE, ...)
# 2/ Enable the mod_shell module and activate the mod_shell_snmp.sh script.
#    Edit the schedwisrv configuration file (schedwisrv.conf) and set
#    the variables as follow:
#       MODULE_LOAD=mod_shell
#       MODULE:mod_shell:CMD_STATUS=/usr/libexec/schedwisrv/mod_shell_snmp.sh
# 3/ Restart the schedwisrv daemon
# 4/ On the SNMP server, you can configure the snmptrapd.conf configuration
#    file to add a handler for the new trap:
#         traphandle SNMPv2-SMI::experimental.2006 /your/command.sh
#    The defined script (/your/command.sh) will then be able to read the trap
#    details from its standard input (stdin).
#


#--
#-- The following variables must be adapted to your environment
#--

#-- The IP address or name of the host running the SNMP server (snmptrapd)
SNMP_SERVER="snmp.yourcompany.com"

#-- Message sent
MESSAGE="Job/jobset $SCHEDWI_JOBPATH new status $SCHEDWI_STATUS_NEW"

#-- Service name
SERVICE="schedwi"


#--
#-- You shouldn't have to modify the script below this comment (except maybe
#-- for snmptrap command)
#--

#-- Set a basic default path as mod_script calls this script without setting
#-- this variable.  The snmptrap command must be in one of these paths
PATH=/bin:/usr/bin:/usr/local/bin:/usr/sbin:/sbin
export PATH

#-- Set the status (0=OK, 1=WARNING, 2=CRITICAL, 3=UNKNOWN) depending
#-- of the jobs status
case $SCHEDWI_STATUS_NEW in
	WAITING)
		RET=0;;
	RUNNING)
		RET=0;;
	COMPLETED)
		RET=0;;
	FAILED)
		RET=2;;
	*)
		RET=3;;
esac


#-- SNMP trap command
snmptrap -v 2c -c public "$SNMP_SERVER" \
	SNMPv2-SMI::experimental.2006 \
	SNMPv2-SMI::experimental.2006.1 s "$SERVICE" \
	SNMPv2-SMI::experimental.2006.2 s "$MESSAGE" \
	SNMPv2-SMI::experimental.2006.3 i "$RET"

exit 0

#-----------------============== End Of File ==============-----------------
